@@ -102,6 +102,10 @@ class Parser:
     def write_packet(self, packet):
 
         if self._queuing['packet'] is True:
+
+            if self.packet_queue.full():
+                self.packet_queue.get_nowait()
+
             self.packet_queue.put_nowait(packet)
 
         if self.logger._logging is True:
@@ -134,6 +138,10 @@ class Parser:
     def write_ascii(self, packet):
 
         if self._queuing['ascii'] is True:
+
+            if self.ascii_queue.full():
+                self.ascii_queue.get_nowait()
+
             ascii_bytes = bytes(packet)
             ascii_packet = {'timestamp_python': datetime.now().timestamp(),
                             'bytes': ascii_bytes}
@@ -180,6 +188,10 @@ class Parser:
                          'failed_packet': packet}
 
         if self._queuing['condition'] is True:
+
+            if self.condition_queue.full():
+                self.condition_queue.get_nowait()
+
             self.condition_queue.put_nowait(failed_packet)
 
         if self.logger._logging is True:
@@ -595,7 +607,7 @@ class Parser:
 
             except struct_error:
                 self.messages.write_warning('Failed to unpack sensor data')
-                self.messages.write_warning(data)
+                self.messages.write_warning(data.decode())
 
             return sensor
 
